@@ -1,4 +1,4 @@
-#![forbid(unsafe_code)]
+#![deny(unsafe_code)]
 
 #[macro_use]
 extern crate log;
@@ -14,10 +14,12 @@ pub mod history;
 pub mod import;
 pub mod kv;
 pub mod login;
+pub mod logout;
 pub mod ordering;
 pub mod record;
 pub mod register;
 pub mod secrets;
 pub mod settings;
+pub mod theme;
 
 mod utils;
