@@ -11,9 +11,9 @@ use eyre::{Context, Result};
 use runtime_format::{FormatKey, FormatKeyError, ParseSegment, ParsedFmt};
 
 use atuin_client::{
-    database::{current_context, Database, Sqlite},
+    database::{Database, Sqlite, current_context},
     encryption,
-    history::{store::HistoryStore, History},
+    history::{History, store::HistoryStore},
     record::sqlite_store::SqliteStore,
     settings::{
         FilterMode::{Directory, Global, Session},
@@ -25,7 +25,7 @@ use atuin_client::{
 use atuin_client::{record, sync};
 
 use log::{debug, warn};
-use time::{macros::format_description, OffsetDateTime};
+use time::{OffsetDateTime, macros::format_description};
 
 use super::search::format_duration_into;
 
@@ -285,7 +285,9 @@ fn parse_fmt(format: &str) -> ParsedFmt {
         Ok(fmt) => fmt,
         Err(err) => {
             eprintln!("ERROR: History formatting failed with the following error: {err}");
-            println!("If your formatting string contains curly braces (eg: {{var}}) you need to escape them this way: {{{{var}}.");
+            println!(
+                "If your formatting string contains curly braces (eg: {{var}}) you need to escape them this way: {{{{var}}."
+            );
             std::process::exit(1)
         }
     }
@@ -323,6 +325,7 @@ impl Cmd {
         Ok(())
     }
 
+    #[cfg(feature = "daemon")]
     async fn handle_daemon_start(settings: &Settings, command: &[String]) -> Result<()> {
         let command = command.join(" ");
 
@@ -384,7 +387,7 @@ impl Cmd {
             return Ok(());
         }
 
-        if !settings.store_failed && h.exit != 0 {
+        if !settings.store_failed && exit > 0 {
             debug!("history has non-zero exit code, and store_failed is false");
 
             // the history has already been inserted half complete. remove it
@@ -425,6 +428,7 @@ impl Cmd {
         Ok(())
     }
 
+    #[cfg(feature = "daemon")]
     #[allow(unused_variables)]
     async fn handle_daemon_end(
         settings: &Settings,
@@ -464,7 +468,7 @@ impl Cmd {
             (true, true) => [Session, Directory],
             (true, false) => [Session, Global],
             (false, true) => [Global, Directory],
-            (false, false) => [settings.filter_mode, Global],
+            (false, false) => [settings.default_filter_mode(), Global],
         };
 
         let history = db
@@ -543,15 +547,16 @@ impl Cmd {
     pub async fn run(self, settings: &Settings) -> Result<()> {
         let context = current_context();
 
+        #[cfg(feature = "daemon")]
         // Skip initializing any databases for start/end, if the daemon is enabled
         if settings.daemon.enabled {
             match self {
                 Self::Start { command } => {
-                    return Self::handle_daemon_start(settings, &command).await
+                    return Self::handle_daemon_start(settings, &command).await;
                 }
 
                 Self::End { id, exit, duration } => {
-                    return Self::handle_daemon_end(settings, &id, exit, duration).await
+                    return Self::handle_daemon_end(settings, &id, exit, duration).await;
                 }
 
                 _ => {}
@@ -601,7 +606,7 @@ impl Cmd {
                 format,
             } => {
                 let last = db.last().await?;
-                let last = last.as_ref().map(std::slice::from_ref).unwrap_or_default();
+                let last = last.as_slice();
                 let tz = timezone.unwrap_or(settings.timezone);
                 print_list(
                     last,
